@@ -31,7 +31,7 @@
 #include <tqstring.h>
 
 #include "spelling.h"
-#include "katapultcatalog.h"
+#include <katapultcatalog.h>
 
 class TQWidget;
 
